@@ -13,7 +13,7 @@ use PDL::Lite '2.012';
 
 ## no critic (ProhibitExplicitReturnUndef)
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use parent 'Statistics::Descriptive::PDL';
 
@@ -356,9 +356,8 @@ sub _geometric_mean {
     my $wts = $self->_get_weights_piddle;
 
     my $exponent = 1 / $self->sum_weights;
-    my $powered = $data * $wts;
-
-    return $powered->dprodover ** $exponent;
+    my $powered = ($data * $wts) ** $exponent;
+    return $powered->dprodover;
 }
 
 sub _mode {
